@@ -1,9 +1,10 @@
 /******************************************************************************
- * This example shows how to do a thread search
  *
- * $Id: threaded_search.cpp 2327 2009-04-22 11:42:33Z scribe $
+ *  threaded_search.cpp -	This example shows how to do a thread search
  *
- * Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: threaded_search.cpp 2923 2013-07-28 20:05:37Z scribe $
+ *
+ * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -18,6 +19,7 @@
  * General Public License for more details.
  *
  */
+
 #include <stdio.h>
 #include <rawtext.h>
 #include <swmgr.h>
@@ -98,13 +100,13 @@ void SearchThread::search()  {
 		return;
 	}
 
-	ListKey scopeList = VerseKey().ParseVerseList("Luke;John;Revelation","", true);
-	for (int i=0; i < scopeList.Count(); ++i) {
-		std::cout << (const char*)*scopeList.GetElement(i) << std::endl;
+	ListKey scopeList = VerseKey().parseVerseList("Luke;John;Revelation","", true);
+	for (int i=0; i < scopeList.getCount(); ++i) {
+		std::cout << (const char*)*scopeList.getElement(i) << std::endl;
 	}
 	SWKey* scope = &scopeList;
 
-	searchResult = module->Search(searchedText, -2, REG_ICASE, scope, 0, &percentUpdate);
+	searchResult = module->search(searchedText, -2, REG_ICASE, scope, 0, &percentUpdate);
 
 	if (!scope)
 		std::cout << "bad scope!" << std::endl;
@@ -125,8 +127,8 @@ int main(int argc, char **argv) {
 	it = manager.Modules.find(argv[1]);
 	if (it == manager.Modules.end()) {
 		fprintf(stderr, "Could not find module [%s].  Available modules:\n",  argv[1]);
-		for (it = manager.Modules.begin(); it != manager.Modules.end(); it++) {
-			fprintf(stderr, "[%s]\t - %s\n", (*it).second->Name(), (*it).second->Description());
+		for (it = manager.Modules.begin(); it != manager.Modules.end(); ++it) {
+			fprintf(stderr, "[%s]\t - %s\n", (*it).second->getName(), (*it).second->getDescription());
 		}
 		exit(-1);
 	}
@@ -144,7 +146,7 @@ int main(int argc, char **argv) {
 			std::cout.flush();
 	};
 
-	std::cout << std::endl << "Number of found items: " << searchThread->searchResult.Count() << std::endl;
+	std::cout << std::endl << "Number of found items: " << searchThread->searchResult.getCount() << std::endl;
 	std::cout << "Finished program" << std::endl;
 	std::cout.flush();
 
