@@ -1,10 +1,10 @@
 /******************************************************************************
- *	swordapi.h	- This file contains an api usable by non-C++
- *					environments
  *
- * $Id: flatapi.h 2324 2009-04-20 18:40:15Z scribe $
+ *  flatapi.h -	This file contains an api usable by non-C++ environments
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: flatapi.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
