@@ -1,12 +1,13 @@
 /*****************************************************************************
- * rawstr.h   - code for class 'RawStr'- a module that reads raw text
- *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
- *			and provides lookup and parsing functions based on
- *			class StrKey
  *
- * $Id: rawstr.h 2303 2009-04-06 13:38:34Z scribe $
+ *  rawstr.h -	code for class 'RawStr'- a module that reads raw text
+ *		files:  ot and nt using indexs ??.bks ??.cps ??.vss
+ *		and provides lookup and parsing functions based on
+ *		class StrKey
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: rawstr.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -36,6 +37,7 @@ class FileDesc;
 class SWDLLEXPORT RawStr {
 	static int instance;		// number of instantiated RawStr objects or derivitives
 	char *path;
+	bool caseSensitive;
 	mutable long lastoff;	 // for caching and optimizing
 	
 
@@ -48,12 +50,12 @@ protected:
 
 public:
 	static char nl;
-	RawStr(const char *ipath, int fileMode = -1);
+	RawStr(const char *ipath, int fileMode = -1, bool caseSensitive = false);
 	virtual ~RawStr();
 	void getIDXBuf(long ioffset, char **buf) const;
 	void getIDXBufDat(long ioffset, char **buf) const;
 	signed char findOffset(const char *key, __u32 *start, __u16 *size, long away = 0, __u32 *idxoff = 0) const;
-	void readText(__u32 start, __u16 *size, char **idxbuf, SWBuf &buf);
+	void readText(__u32 start, __u16 *size, char **idxbuf, SWBuf &buf) const;
 	static signed char createModule(const char *path);
 };
 
