@@ -1,8 +1,26 @@
 /******************************************************************************
- *  rawverse.h   - code for class 'RawVerse'- a module that reads raw text
+ *
+ *  rawverse.h -	code for class 'RawVerse'- a module that reads raw text
  *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
  *			and provides lookup and parsing functions based on
  *			class VerseKey
+ *
+ * $Id: rawverse.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
 #ifndef RAWVERSE_H
@@ -33,7 +51,7 @@ public:
 	RawVerse(const char *ipath, int fileMode = -1);
 	virtual ~RawVerse();
 	void findOffset(char testmt, long idxoff, long *start,	unsigned short *end) const;
-	void readText(char testmt, long start, unsigned short size, SWBuf &buf);
+	void readText(char testmt, long start, unsigned short size, SWBuf &buf) const;
 	static char createModule(const char *path, const char *v11n = "KJV");
 };
 
