@@ -1,10 +1,11 @@
 /******************************************************************************
- *  swmgr.h   - definition of class SWMgr used to interact with an install
- *				base of sword modules.
  *
- * $Id: swmgr.h 2340 2009-04-26 13:51:42Z scribe $
+ *  swmgr.h -	definition of class SWMgr used to interact with an install
+ *		base of sword modules.
  *
- * Copyright 1998-2008 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: swmgr.h 2941 2013-08-03 07:08:24Z chrislit $
+ *
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -42,12 +43,13 @@
  *	some of the existing ones.  They can always use help, and will also prove to be good examples
  *	if you decide to start a new project.
  *
- * Well known frontends are:\n
- *	-BibleTime (http://www.bibletime.info)\n
- *	-BPBible (http://bpbible.com)\n
- *	-MacSword (http://www.macsword.com)\n
- *	-Xiphos (http://xiphos.org)\n
- *	-SWORD for Windows (http://crosswire.org/sword/software/biblecs/)\n
+ * Well known frontends are:
+ *	-BibleTime (http://www.bibletime.info)
+ *	-BPBible (http://bpbible.com)
+ *	-Eloquent (http://www.macsword.com)
+ *	-PocketSword (http://crosswire.org/pocketsword/)
+ *	-SWORD for Windows (http://crosswire.org/sword/software/biblecs/)
+ *	-Xiphos (http://xiphos.org) 
  */
 
 #ifndef SWMGR_H
@@ -84,11 +86,9 @@ class SWOptionFilter;
  * SWMgr exposes an installed module set and can be asked to configure the desired
  *	markup and options which modules will produce.
  *
- * @version $Id: swmgr.h 2340 2009-04-26 13:51:42Z scribe $
+ * @version $Id: swmgr.h 2941 2013-08-03 07:08:24Z chrislit $
  */
 class SWDLLEXPORT SWMgr {
-
-
 private:
 	bool mgrModeMultiMod;
 	bool augmentHome;
@@ -100,7 +100,7 @@ protected:
 	SWConfig *mysysconfig;
 	SWConfig *homeConfig;
 	void CreateMods(bool multiMod = false);
-	SWModule *CreateMod(const char *name, const char *driver, ConfigEntMap &section);
+	virtual SWModule *createModule(const char *name, const char *driver, ConfigEntMap &section);
 	void DeleteMods();
 	char configType;		// 0 = file; 1 = directory
 	OptionFilterMap optionFilters;
@@ -111,6 +111,7 @@ protected:
 	SWFilter *teiplain;
 	SWOptionFilter *transliterator;
 	FilterList cleanupFilters;
+	FilterMap extraFilters;
 	StringList options;
 	virtual void init(); // use to initialize before loading modules
 	virtual char AddModToConfig(FileDesc *conffd, const char *fname);
@@ -157,6 +158,14 @@ protected:
 
 public:
 
+	// constants which represent module types used in SWModule::getType
+	static const char *MODTYPE_BIBLES;
+	static const char *MODTYPE_COMMENTARIES;
+	static const char *MODTYPE_LEXDICTS;
+	static const char *MODTYPE_GENBOOKS;
+	static const char *MODTYPE_DAILYDEVOS;
+
+
 	static bool isICU;
 	static const char *globalConfPath;
 	static SWBuf getHomeDir();
