@@ -1,10 +1,11 @@
 /******************************************************************************
- *  ztext.h   - code for class 'zText'- a module that reads compressed text
- *				files: ot and nt using indexs ??.vss
  *
- * $Id: ztext.h 2303 2009-04-06 13:38:34Z scribe $
+ *  ztext.h -	code for class 'zText'- a module that reads compressed text
+ *		files: ot and nt using indexs ??.vss
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: ztext.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1996-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -59,13 +60,13 @@ public:
 			const char *versification = "KJV");
 
 	virtual ~zText();
-	virtual SWBuf &getRawEntryBuf();
+	virtual SWBuf &getRawEntryBuf() const;
 
 	virtual void increment(int steps = 1);
 	virtual void decrement(int steps = 1) { increment(-steps); }
 
   // write interface ----------------------------
-	virtual bool isWritable();
+	virtual bool isWritable() const;
 	static char createModule(const char *path, int blockBound, const char *v11n = "KJV") {
 		return zVerse::createModule(path, blockBound, v11n);
 	}
@@ -75,7 +76,7 @@ public:
 	virtual void deleteEntry();	// Delete current module entry
   // end write interface ------------------------
   
-	virtual void rawZFilter(SWBuf &buf, char direction = 0) { rawFilter(buf, (SWKey *)(long)direction); }// hack, use key as direction for enciphering
+	virtual void rawZFilter(SWBuf &buf, char direction = 0) const { rawFilter(buf, (SWKey *)(long)direction); }// hack, use key as direction for enciphering
 
 	// swcacher interface ----------------------
 	virtual void flush() { flushCache(); }
