@@ -1,11 +1,12 @@
 /******************************************************************************
- *  rawverse.cpp   - code for class 'RawVerse'- a module that reads raw text
+ *
+ *  rawverse.cpp -	code for class 'RawVerse'- a module that reads raw text
  *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
  *			and provides lookup and parsing functions based on
  *			class VerseKey
  *
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -149,7 +150,7 @@ void RawVerse::findOffset(char testmt, long idxoff, long *start, unsigned short
  *
  */
 
-void RawVerse::readText(char testmt, long start, unsigned short size, SWBuf &buf) {
+void RawVerse::readText(char testmt, long start, unsigned short size, SWBuf &buf) const {
 	buf = "";
 	buf.setFillByte(0);
 	buf.setSize(size + 1);
@@ -278,15 +279,15 @@ char RawVerse::createModule(const char *ipath, const char *v11n)
 
 	VerseKey vk;
 	vk.setVersificationSystem(v11n);
-	vk.Headings(1);
+	vk.setIntros(1);
 
 	__s32 offset = 0;
 	__u16 size = 0;
 	offset = archtosword32(offset);
 	size = archtosword16(size);
 
-	for (vk = TOP; !vk.Error(); vk++) {
-		if (vk.Testament() < 2) {
+	for (vk = TOP; !vk.popError(); vk++) {
+		if (vk.getTestament() < 2) {
 			fd->write(&offset, 4);
 			fd->write(&size, 2);
 		}
