@@ -1,11 +1,14 @@
 /******************************************************************************
- *  rawverse.cpp   - code for class 'RawVerse4'- a module that reads raw text
- *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
+ *
+ *  rawverse4.cpp -	code for class 'RawVerse4'- a module that reads raw
+ *			text files:
+ *			ot and nt using indexs ??.bks ??.cps ??.vss
  *			and provides lookup and parsing functions based on
  *			class VerseKey
  *
+ * $Id: rawverse4.cpp 2833 2013-06-29 06:40:28Z chrislit $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2007-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -149,7 +152,7 @@ void RawVerse4::findOffset(char testmt, long idxoff, long *start, unsigned long
  *
  */
 
-void RawVerse4::readText(char testmt, long start, unsigned long size, SWBuf &buf) {
+void RawVerse4::readText(char testmt, long start, unsigned long size, SWBuf &buf) const {
 	buf = "";
 	buf.setFillByte(0);
 	buf.setSize(size + 1);
@@ -278,14 +281,14 @@ char RawVerse4::createModule(const char *ipath, const char *v11n)
 
 	VerseKey vk;
 	vk.setVersificationSystem(v11n);
-	vk.Headings(1);
+	vk.setIntros(1);
 	__u32 offset = 0;
 	__u32 size = 0;
 	offset = archtosword32(offset);
 	size   = archtosword32(size);
 
-	for (vk = TOP; !vk.Error(); vk++) {
-		if (vk.Testament() < 2) {
+	for (vk = TOP; !vk.popError(); vk++) {
+		if (vk.getTestament() < 2) {
 			fd->write(&offset, 4);
 			fd->write(&size, 4);
 		}
