@@ -2,7 +2,7 @@
  *
  *  osishtmlhref.cpp -	OSIS to HTML with hrefs filter
  * 
- * $Id: osishtmlhref.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: osishtmlhref.cpp 2994 2013-12-28 05:54:40Z greg.hellings $
  *
  * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -371,7 +371,7 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 		}
 
 		// <lb.../>
-		else if (!strcmp(tag.getName(), "lb")) {
+		else if (!strcmp(tag.getName(), "lb") && (strcmp(tag.getAttribute("type"), "x-optional"))) {
 			outText("<br />", buf, u);
 			userData->supressAdjacentWhitespace = true;
 		}
