@@ -1,10 +1,11 @@
 /******************************************************************************
  *
- * OSISScripref -	SWFilter descendant to hide or show scripture references
- *			in an OSIS module.
+ *  osisscripref.cpp -	SWFilter descendant to hide or show scripture
+ *			references in an OSIS module
  *
+ * $Id: osisscripref.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -25,16 +26,23 @@
 #include <swmodule.h>
 #include <utilxml.h>
 
+
 SWORD_NAMESPACE_START
 
-const char oName[] = "Cross-references";
-const char oTip[] = "Toggles Scripture Cross-references On and Off if they exist";
+namespace {
 
-const SWBuf choices[3] = {"Off", "On", ""};
-const StringList oValues(&choices[0], &choices[2]);
+	static const char oName[] = "Cross-references";
+	static const char oTip[]  = "Toggles Scripture Cross-references On and Off if they exist";
 
-OSISScripref::OSISScripref() : SWOptionFilter(oName, oTip, &oValues) {
-	setOptionValue("On");
+	static const StringList *oValues() {
+		static const SWBuf choices[3] = {"On", "Off", ""};
+		static const StringList oVals(&choices[0], &choices[2]);
+		return &oVals;
+	}
+}
+
+
+OSISScripref::OSISScripref() : SWOptionFilter(oName, oTip, oValues()) {
 }
 
 
