@@ -1,10 +1,10 @@
 /***************************************************************************
- *                    teirtf.cpp  -  TEI to RTF filter
- *                            -------------------
- *   begin                : 2006-07-03
- *   copyright            : 2006 by CrossWire Bible Society
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *  teirtf.cpp -	TEI to RTF filter
+ *
+ * $Id: teirtf.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2006-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -34,8 +34,8 @@ TEIRTF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : Basic
 	BiblicalText = false;
 	inOsisRef = false;
 	if (module) {
-		version = module->Name();
-		BiblicalText = (!strcmp(module->Type(), "Biblical Texts"));
+		version = module->getName();
+		BiblicalText = (!strcmp(module->getType(), "Biblical Texts"));
 	}
 }
 
