@@ -1,10 +1,11 @@
 /******************************************************************************
  *
- * utf8html -	SWFilter descendant to convert a UTF-8 stream to HTML escapes
+ *  utf8html.cpp -	SWFilter descendant to convert a UTF-8 stream to
+ *			HTML escapes
  *
+ * $Id: utf8html.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -25,8 +26,10 @@
 #include <utf8html.h>
 #include <swbuf.h>
 
+
 SWORD_NAMESPACE_START
 
+
 UTF8HTML::UTF8HTML() {
 }
 
@@ -34,14 +37,11 @@ UTF8HTML::UTF8HTML() {
 char UTF8HTML::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 {
 	unsigned char *from;
-	int len;
         char digit[10];
         unsigned long ch;
 	 if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
 		return (char)-1;
 
-	len = strlen(text.c_str()) + 2;						// shift string to right of buffer
-
 	SWBuf orig = text;
   	from = (unsigned char *)orig.c_str();
 
@@ -82,4 +82,6 @@ char UTF8HTML::processText(SWBuf &text, const SWKey *key, const SWModule *module
 	return 0;
 }
 
+
 SWORD_NAMESPACE_END
+
