@@ -1,10 +1,11 @@
 #!/bin/sh
 #******************************************************************************
-# Convenience script specifying most common development options to ./configure
+#  usrinst.sh -	Convenience script specifying most common development options
+#		to ./configure
 #
-# $Id: usrinst.sh 2486 2009-12-07 04:02:43Z scribe $
+# $Id: usrinst.sh 2986 2013-10-05 12:32:49Z scribe $
 #
-# Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
+# Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
 #	CrossWire Bible Society
 #	P. O. Box 2528
 #	Tempe, AZ  85280-2528
@@ -21,15 +22,21 @@
 #
 
 OPTIONS="--prefix=/usr $OPTIONS"
-OPTIONS="--libdir=/usr/lib64 $OPTIONS"
+if [ -d /usr/lib64 ]
+then
+	OPTIONS="--libdir=/usr/lib64 $OPTIONS"
+else
+	OPTIONS="--libdir=/usr/lib $OPTIONS"
+fi
 OPTIONS="--sysconfdir=/etc $OPTIONS"
 OPTIONS="--without-conf $OPTIONS"
 OPTIONS="--disable-shared $OPTIONS"
-OPTIONS="--enable-debug $OPTIONS"
+#OPTIONS="--enable-debug $OPTIONS"
 #OPTIONS="--enable-profile $OPTIONS"
 
-#OPTIONS="--without-icu $OPTIONS"
+#OPTIONS="--with-cxx11regex $OPTIONS"
 #OPTIONS="--with-icusword $OPTIONS"
+#OPTIONS="--without-icu $OPTIONS"
 #OPTIONS="--without-clucene $OPTIONS"
 #OPTIONS="--without-curl $OPTIONS"
 
